package org.jenkinsci.plugins.p4_client.credentials;

import hudson.Extension;
import hudson.Util;
import hudson.util.Secret;

import org.kohsuke.stapler.DataBoundConstructor;

import com.cloudbees.plugins.credentials.CredentialsDescriptor;
import com.cloudbees.plugins.credentials.CredentialsScope;

import edu.umd.cs.findbugs.annotations.CheckForNull;
import edu.umd.cs.findbugs.annotations.NonNull;

public class P4PasswordImpl extends P4StandardCredentials {

	/**
	 * Ensure consistent serialisation.
	 */
	private static final long serialVersionUID = 1L;

	@NonNull
	private final String p4port;
	private final TrustImpl ssl;

	@NonNull
	private final String username;

	@NonNull
	private final Secret password;

	@DataBoundConstructor
	public P4PasswordImpl(@CheckForNull CredentialsScope scope,
			@CheckForNull String id, @CheckForNull String description,
			@CheckForNull String p4port, TrustImpl ssl,
			@CheckForNull String username, @CheckForNull String password) {
		super(scope, id, description, p4port, ssl, username);
		this.p4port = Util.fixNull(p4port);
		this.ssl = ssl;
		this.username = Util.fixNull(username);
		this.password = Secret.fromString(password);
	}

	@NonNull
	public String getP4port() {
		return p4port;
	}

	public boolean isSsl() {
		return (ssl == null) ? false : true;
	}

	public String getTrust() {
		return (ssl == null) ? null : ssl.getTrust();
	}

	@NonNull
	public String getUsername() {
		return username;
	}

	@NonNull
	public Secret getPassword() {
		return password;
	}

	@Extension
	public static class DescriptorImpl extends CredentialsDescriptor {

		@Override
		public String getDisplayName() {
			return "Perforce Password Credential";
		}

	}
}
